pygerber.parser.blender.apertures.region module
===============================================

.. automodule:: pygerber.parser.blender.apertures.region
   :members:
   :undoc-members:
   :show-inheritance:
